//
// nono
// Copyright (C) 2020 nono project
// Licensed under nono-license.txt
//

//
// ホストネットワークの none ドライバ
//

#include "netdriver_none.h"

// コンストラクタ
NetDriverNone::NetDriverNone(HostDevice *hostdev_)
	: inherited(hostdev_, "none")
{
}

// デストラクタ
NetDriverNone::~NetDriverNone()
{
}

// パケットを送信する
void
NetDriverNone::Write(const void *buf, int buflen)
{
}

// パケットを受信する
int
NetDriverNone::Read(NetPacket *p)
{
	return NODATA;
}
